@@ -1,12 +1,15 @@
 <?php
 require_once 'includes.php';
 
-/* $Id: index.php,v 1.4 2008-01-18 12:02:37 sondberg Exp $
+/* $Id: index.php,v 1.6 2008-05-14 09:28:47 jakub Exp $
  * --------------------------------------------------------------------------
  * The main script - this dispatches control to page handers, action handlers
  * and finally to an xslt stylesheet.
  */
 
+if (ini_get("magic_quotes_gpc"))
+    echo "The magic_quotes_gpc php directive has to be switched off.";
+
 main($_REQUEST);
 
 function main (&$r) 
@@ -20,9 +23,29 @@ function main (&$r)
     }
 
     if ($r['debug']) {
-        echo "REQUEST:<pre>";
-        print_r($r);
-        echo "</pre>";
+        $debug_opts = explode(";", $r['debug']);
+        foreach ($debug_opts as $debug_opt) {
+            switch ($debug_opt) {
+                case "req":
+                    echo "<b>REQUEST:</b>";
+                    echo "<pre>";
+                    print_r($r);
+                    echo "</pre>";
+                    break;
+                case "srv":
+                    echo "<b>SERVER:</b>";
+                    echo "<pre>";
+                    print_r($_SERVER);
+                    echo "</pre>";
+                    break;
+                case "inc":
+                    echo "<b>INCLUDE PATH:</b>";
+                    echo "<pre>";
+                    echo get_include_path();
+                    echo "</pre>";
+                    break;
+            }
+        }
     }
 
     if (!isset($r['page'])) {
